Introduction
============

`SNMP`_ is an universal protocol which can be used to monitor and manage
networked devices. ``debops.snmpd`` role can be used to configure ``snmpd``
service on a Debian or Ubuntu host, which in turn can be used to monitor that
host resources like CPU utilization, memory and storage capacity, network usage
and more.

.. _SNMP: https://en.wikipedia.org/wiki/Simple_Network_Management_Protocol

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
